@@ -1,5 +1,5 @@
 package Device::Firewall::PaloAlto::Op::Interface;
-$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.8';
+$Device::Firewall::PaloAlto::Op::Interface::VERSION = '0.1.9';
 use strict;
 use warnings;
 use 5.010;
@@ -15,16 +15,28 @@ sub _new {
     my $class = shift;
     my ($api_return) = @_;
 
+    return $api_return unless $api_return;
+
     return bless $api_return, $class;
 }
 
 
 
+
 sub name { return $_[0]->{name} }
+
 sub state { return $_[0]->{state} }
+
 sub ip { return $_[0]->{ip} }
+
 sub vsys { return $_[0]->{vsys} }
-sub zone { return $_[0]->{zone} }
+
+sub zone { 
+    my $self = shift;
+    return ref $self->{zone} eq 'HASH'
+        ? ''
+        : $self->{zone}
+}
 
 1;
 
@@ -40,13 +52,11 @@ Device::Firewall::PaloAlto::Op::Interface - Palo Alto firewall interface
 
 =head1 VERSION
 
-version 0.1.8
-
-=head1 SYNOPSIS
+version 0.1.9
 
 =head1 DESCRIPTION
 
-=head1 ERRORS 
+This module represents a Palo Alo interface, both physical and logical.
 
 =head1 METHODS
 
@@ -66,6 +76,11 @@ Returns the IPv4 address and CIDR of the interface (e.g '192.0.2.0/24') or the e
 
 Returns the vsys ID (1, 2, etc) of the vsys the interface is a member of.
 
+=head2 zone
+
+Returns the name of the zone the interface is in.
+If the interface is not a member of a zone, returns an empty string.
+
 =head1 AUTHOR
 
 Greg Foletta <greg@foletta.org>
