@@ -1,10 +1,11 @@
 package Device::Firewall::PaloAlto::Op::Interfaces;
-$Device::Firewall::PaloAlto::Op::Interfaces::VERSION = '0.1.8';
+$Device::Firewall::PaloAlto::Op::Interfaces::VERSION = '0.1.9';
 use strict;
 use warnings;
 use 5.010;
 
 use Device::Firewall::PaloAlto::Op::Interface;
+use Device::Firewall::PaloAlto::Errors qw(fatal_error);
 
 use parent qw(Device::Firewall::PaloAlto::JSON);
 
@@ -61,7 +62,7 @@ sub _new {
 sub interface { 
     my ($self, $name) = @_;
 
-    return Class::Error->new("No such interface '$name'") unless defined $self->{$name};
+    return fatal_error("No such interface '$name'") unless defined $self->{$name};
 
     return Device::Firewall::PaloAlto::Op::Interface->_new($self->{$name});
 }
@@ -94,7 +95,7 @@ Device::Firewall::PaloAlto::Op::Interfaces - new module
 
 =head1 VERSION
 
-version 0.1.8
+version 0.1.9
 
 =head1 SYNOPSIS
 
